@@ -243,7 +243,7 @@ class Media(object):
         """
         self.inputs = _inputs
 
-        first_input = dict(copy.deepcopy(_inputs.inputs[0]))
+        first_input = dict(copy.copy(_inputs.inputs[0]))
         self.input = first_input.get('i', None)
         self.input_temp = first_input.get('is_tmp', False)
 
