@@ -15,9 +15,10 @@ import shlex
 import subprocess
 import threading
 import logging
+import time
 
 from ffmpeg_streaming._hls_helper import HLSKeyInfoFile
-from ffmpeg_streaming._utiles import get_time
+from ffmpeg_streaming._utiles import get_time, time_left
 
 
 def _p_open(commands, **options):
@@ -69,8 +70,9 @@ class Process(object):
         @TODO: add documentation
         """
         duration = 1
-        time = 0
+        _time = 0
         log = []
+        start_time = time.time()
 
         while True:
             line = self.process.stdout.readline().strip()
@@ -84,13 +86,9 @@ class Process(object):
                 getattr(self.media, 'key_rotation').rotate_key(line)
 
             if callable(self.monitor):
-                if duration < 2 and get_time('Duration: ', line) is not None:
-                    duration = get_time('Duration: ', line)
-
-                if get_time('time=', line):
-                    time = get_time('time=', line)
-
-                self.monitor(line, duration, time)
+                duration = get_time('Duration: ', line, duration)
+                _time = get_time('time=', line, _time)
+                self.monitor(line, duration, _time, time_left(start_time, _time, duration), self.process)
 
         Process.out = log
 
